@@ -3,9 +3,9 @@
 File:
     ex_analysis.py
 
-Desrciption:
+Description:
     Basic example using analysis functions.
-    Downloads THEMIS data and plots it.
+    Download THEMIS data, subtract average, and plot it.
 
 """
 
@@ -14,17 +14,23 @@ import pytplot
 
 
 def ex_analysis():
-    # Print the installed version of pyspedas
-    pyspedas.version()
+
     # Delete any existing pytplot variables
     pytplot.del_data()
+
     # Download THEMIS state data for 2015-12-31
-    pyspedas.load_data('themis', '2015-12-31', ['tha'], 'state', 'l1')
+    time_range = ['2015-12-31 00:00:00', '2015-12-31 23:59:59']
+    pyspedas.themis.state(probe='a', trange=time_range)
+
     # Use some analysis functions on tplot variables
     pyspedas.subtract_average('tha_pos')
     pyspedas.subtract_median('tha_pos')
+
     # Plot
     pytplot.tplot(["tha_pos", "tha_pos-d", "tha_pos-m"])
 
+    # Return 1 as indication that the example finished without problems.
+    return 1
+
 # Run the example code
 # ex_analysis()
