@@ -3,7 +3,7 @@
 File:
     ex_create.py
 
-Desrciption:
+Description:
     Creates a new pytplot object and applies analysis functions.
 
 """
@@ -11,29 +11,36 @@ Desrciption:
 import pyspedas
 import pytplot
 import numpy
+from pyspedas.utilities.time_double import time_float
 
 
 def ex_create():
+
     # Delete any existing pytplot variables
     pytplot.del_data()
+
     # Create a sin wave plot
     a = list(range(0, 101))
-    b = [2.0/100.0*numpy.pi*s for s in a]
-    c = pyspedas.time_float('2017-01-01')
+    b = [2.0 / 100.0 * numpy.pi * s for s in a]
+    c = time_float('2017-01-01')
     x = list()
     y = list()
     for i in range(len(b)):
-        x.append(c+60.0/(2*numpy.pi)*60.0*b[i])
-        y.append(1000.0*numpy.sin(b[i]))
+        x.append(c + 60.0 / (2 * numpy.pi) * 60.0 * b[i])
+        y.append(1000.0 * numpy.sin(b[i]))
 
     # Store data
     pytplot.store_data('sinx', data={'x': x, 'y': y})
-    # Apply tclip
-    pyspedas.tclip('sinx', -800.0, 800.0)
+
+    # Apply yclip
+    pyspedas.yclip('sinx', -800.0, 800.0)
+
     # Remove NaN values
     pyspedas.tdeflag('sinx-clip')
+
     # Interpolate
-    pyspedas.tinterpol(['sinx-clip-deflag'], ['sinx'], 'quadratic')
+    pyspedas.tinterpol(['sinx-clip-deflag'], 'sinx', 'quadratic')
+
     # Plot
     pytplot.ylim('sinx', -1100.0, 1100.0)
     pytplot.ylim('sinx-clip', -1100.0, 1100.0)
@@ -43,5 +50,8 @@ def ex_create():
     pytplot.tplot(['sinx', 'sinx-clip', 'sinx-clip-deflag',
                    'sinx-clip-deflag-itrp'])
 
+    # Return 1 as indication that the example finished without problems.
+    return 1
+
 # Run the example code
 # ex_create()
