@@ -4,8 +4,8 @@ CONFIG = {'local_data_dir': 'geotail_data/',
           'remote_data_dir': 'https://spdf.sci.gsfc.nasa.gov/pub/data/geotail/'}
 
 # override local data directory with environment variables
-if os.environ.get('ROOT_DATA_DIR'):
-    CONFIG['local_data_dir'] = os.sep.join([os.environ['ROOT_DATA_DIR'], 'geotail'])
+if os.environ.get('SPEDAS_DATA_DIR'):
+    CONFIG['local_data_dir'] = os.sep.join([os.environ['SPEDAS_DATA_DIR'], 'geotail'])
 
 if os.environ.get('GEOTAIL_DATA_DIR'):
     CONFIG['local_data_dir'] = os.environ['GEOTAIL_DATA_DIR']
\ No newline at end of file
