@@ -12,8 +12,8 @@ CONFIG = {'local_data_dir': 'pydata',
           'no_download': False}
 
 # override local data directory with environment variables
-if os.environ.get('ROOT_DATA_DIR'):
-	CONFIG['local_data_dir'] = os.sep.join([os.environ['ROOT_DATA_DIR'], 'mms'])
+if os.environ.get('SPEDAS_DATA_DIR'):
+	CONFIG['local_data_dir'] = os.sep.join([os.environ['SPEDAS_DATA_DIR'], 'mms'])
 
 if os.environ.get('MMS_DATA_DIR'):
 	CONFIG['local_data_dir'] = os.environ['MMS_DATA_DIR']
\ No newline at end of file
